##--------------------------------------------------------------------------------------------------------
## SCRIPT : Illustrate correlation decay
##
## Authors : Matthieu Authier
## Last update : 2019-02-03
## R version 3.5.1 (2018-07-02) -- "Feather Spray"
## Copyright (C) 2018 The R Foundation for Statistical Computing
## Platform: x86_64-w64-mingw32/x64 (64-bit)
##--------------------------------------------------------------------------------------------------------

lapply(c("hett", "arm", "ggplot2", "dplyr"), library, character.only=TRUE)

### clean up
rm(list = ls())

setwd(WorkDir <- getwd()) # set path to your working directory
DataDir <- paste(WorkDir, "data", sep = "/")
OutDir <- paste(WorkDir, "output", sep = "/")

n <- 5
rw <- function(n) {
  rho_start <- runif(1, 0.70, 0.95)
  eps <- rchisq(n - 1, df = 2)
  eps <- rev(cumsum(eps)) / sum(eps)
  return(c(1, rho_start * eps))
}

n_sim <- 1000
### n = 3
set.seed(20190203)
n <- 3
dd <- as.data.frame(t(replicate(n_sim, rw(n = n))))
names(dd) <- as.character(1:n)

dd$sim <- 1:n_sim
dd$n <- n
rho <- reshape2::melt(dd, id = c("sim", "n"))

### n = 10
n <- 10
set.seed(20190203)
dd <- as.data.frame(t(replicate(n_sim, rw(n = n))))
names(dd) <- as.character(1:n)

dd$sim <- 1:n_sim
dd$n <- n
rho <- rbind(rho, reshape2::melt(dd, id = c("sim", "n")))

### n = 20
n <- 20
set.seed(20190203)
dd <- as.data.frame(t(replicate(n_sim, rw(n = n))))
names(dd) <- as.character(1:n)

dd$sim <- 1:n_sim
dd$n <- n
rho <- rbind(rho, reshape2::melt(dd, id = c("sim", "n")))

### n = 30
n <- 30
set.seed(20190203)
dd <- as.data.frame(t(replicate(n_sim, rw(n = n))))
names(dd) <- as.character(1:n)

dd$sim <- 1:n_sim
dd$n <- n
rho <- rbind(rho, reshape2::melt(dd, id = c("sim", "n")))

rm(dd)
rho$variable <- as.numeric(as.character(rho$variable))

theme_set(theme_bw(base_size = 16))
### set significance to 0.05
ggplot(data = rho,
       aes(x = variable, y = value, group = sim)) +
  geom_line(alpha = 0.05) +
  geom_hline(yintercept = 0.0, linetype = 'dotted', color = "red") +
  facet_wrap(.~ n , scales = "free_x", ncol = 2) +
  scale_x_continuous(name = "sample size", breaks = c(1:3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Correlation", breaks = seq(0, 1, 0.2)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "Correlation.png", sep = "/"), 
       dpi = 600, height = 15, width = 20, unit = "cm"
       )
