##--------------------------------------------------------------------------------------------------------
## SCRIPT : Aggregate results
##
## Authors : Matthieu Authier
## Last update : 2019-02-05
## R version 3.5.1 (2018-07-02) -- "Feather Spray"
## Copyright (C) 2018 The R Foundation for Statistical Computing
## Platform: x86_64-w64-mingw32/x64 (64-bit)
##--------------------------------------------------------------------------------------------------------

lapply(c("arm", "ggplot2", "dplyr"), library, character.only=TRUE)

### clean up
rm(list = ls())

setwd(WorkDir <- getwd()) # set path to your working directory
DataDir <- paste(WorkDir, "data", sep = "/")
OutDir <- paste(WorkDir, "output", sep = "/")

sum_stat <- function(upper) {
  load(paste(OutDir, "/Trends_CV", upper, ".RData", sep = ""))
  if(upper == 0.1) { results <- results_1; rm(results_1) }
  if(upper == 0.2) { results <- results_2; rm(results_2) }
  if(upper == 0.3) { results <- results_3; rm(results_3) }
  if(upper == 0.4) { results <- results_4; rm(results_4) }
  if(upper == 0.5) { results <- results_5; rm(results_5) }
  results$dataset <- rep(1:10000, each = 3, times = length(study_length) * length(beta))
  results <- as.data.frame(subset(results, conv == 1))
  dd <- results %>%
    group_by(n, logbeta, model) %>%
    summarize(sample_size = n(),
              mean_est = mean(theta),
              sd_est = sd(theta),
              mean_se = mean(se),
              sd_se = sd(se),
              mean_pval = mean(pval),
              power1 = mean(ifelse(pval < 0.05, 1, 0)),
              power2 = mean(ifelse(pval < 0.20, 1, 0)),
              typeS1 = mean(ifelse(pval < 0.05, 1, NA) * ifelse(exp(theta) < 1, 0, 1), na.rm = TRUE),
              typeS2 = mean(ifelse(pval < 0.20, 1, NA) * ifelse(exp(theta) < 1, 0, 1), na.rm = TRUE),
              typeM1 = mean(ifelse(pval < 0.05, 1, NA) * (exp(theta) / exp(logbeta)), na.rm = TRUE),
              typeM2 = mean(ifelse(pval < 0.20, 1, NA) * (exp(theta) / exp(logbeta)), na.rm = TRUE),
              cover1 = mean(ifelse(theta + qt(0.025, df = n - 1) * se > logbeta, 0, ifelse(theta + qt(0.975, df = n - 1) * se < logbeta, 0, 1))),
              cover2 = mean(ifelse(theta + qt(0.1, df = n - 1) * se > logbeta, 0, ifelse(theta + qt(0.9, df = n - 1) * se < logbeta, 0, 1))),
              ccover1 = mean(ifelse(pval < 0.05, 1, NA) * ifelse(theta + qt(0.025, df = n - 1) * se > logbeta, 0, ifelse(theta + qt(0.975, df = n - 1) * se < logbeta, 0, 1)), na.rm = TRUE),
              ccover2 = mean(ifelse(pval < 0.20, 1, NA) * ifelse(theta + qt(0.1, df = n - 1) * se > logbeta, 0, ifelse(theta + qt(0.9, df = n - 1) * se < logbeta, 0, 1)), na.rm = TRUE)
              )
  dd$cv <- upper
  return(dd)
}

test <- NULL
for(i in seq(0.1, 0.5, 0.1)) {
  test <- rbind(test,
                sum_stat(i)
                )
}; rm(i)

write.table(test, file = paste(OutDir, "/", lubridate::today(), "_all_results.txt", sep = ""),
            sep = "\t", quote = FALSE, col.names = TRUE, row.names = FALSE
            )
