##--------------------------------------------------------------------------------------------------------
## SCRIPT : Graphics
##
## Authors : Matthieu Authier
## Last update : 2019-02-05
## R version 3.5.1 (2018-07-02) -- "Feather Spray"
## Copyright (C) 2018 The R Foundation for Statistical Computing
## Platform: x86_64-w64-mingw32/x64 (64-bit)
##--------------------------------------------------------------------------------------------------------

lapply(c("arm", "ggplot2", "dplyr"), library, character.only=TRUE)

### clean up
rm(list = ls())

setwd(WorkDir <- getwd()) # set path to your working directory
DataDir <- paste(WorkDir, "data", sep = "/")
OutDir <- paste(WorkDir, "output", sep = "/")

test <- read.table(paste(OutDir, "20190125_all_results.txt", sep = "/"),
                   header = TRUE, colClasses = c("numeric", "character")[c(1, 1, 2, rep(1, 14))]
                   )

test$prior <- ifelse(test$model == "glm", "unregularized", NA)
test$prior <- ifelse(test$model == "arm_strong", "informative", test$prior)
test$prior <- ifelse(test$model == "arm_weak", "weakly\ninformative", test$prior)
test$prior <- factor(as.character(test$prior),
                     levels = c("unregularized", "informative", "weakly\ninformative")
                     )

theme_set(theme_bw(base_size = 16))
### set significance to 0.05
ggplot(data = test,
       aes(x = n, y = power1, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.8, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Power", breaks = seq(0, 1, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "Power_significance5.png", sep = "/"), 
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = 100 * (1 - exp(mean_est) / exp(logbeta)), group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.0, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "bias (%)", breaks = seq(-25, 10, 5)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "bias.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = typeS1, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.0, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_sqrt(name = "Type S error\nrate (%)", breaks = seq(0, 1, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "typeS_significance5.png", sep = "/"), 
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = typeM1, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 1.0, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Type M error\n(exaggeration factor)", breaks = seq(0.75, 1.20, 0.05)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.75, 1.20)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "typeM_significance5.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = cover1, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.95, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Coverage", breaks = seq(0.0, 1.0, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.0, 1.0)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "coverage_significance5.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = ccover1, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.95, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Coverage", breaks = seq(0.0, 1.0, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.0, 1.0)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "post_selection_coverage_significance5.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

### set significance to 0.2
ggplot(data = test,
       aes(x = n, y = power2, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.8, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Power", breaks = seq(0, 1, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "Power_significance20.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = typeS2, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.0, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_sqrt(name = "Type S error\nrate (%)", breaks = seq(0, 1, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "typeS_significance20.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = typeM2, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 1.0, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Type M error\n(exaggeration factor)", breaks = seq(0.75, 1.20, 0.05)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.75, 1.20)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "typeM_significance20.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = cover2, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.8, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Coverage", breaks = seq(0.0, 1.0, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.0, 1.0)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "coverage_significance20.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )

ggplot(data = test,
       aes(x = n, y = ccover2, group = logbeta, color = exp(logbeta))) +
  geom_line() +
  geom_hline(yintercept = 0.8, linetype = 'dotted', color = "red") +
  facet_grid(prior~cv) +
  scale_x_continuous(name = "sample size", breaks = c(3, seq(5, 30, 5))) +
  scale_y_continuous(name = "Coverage", breaks = seq(0.0, 1.0, 0.2)) +
  scale_color_gradientn(name = "Decrease (%)",
                        colours = viridisLite::viridis(256),
                        breaks = seq(0.5, 1.0, 0.1),
                        labels = 100 * (1 - seq(0.5, 1.0, 0.1)),
                        limits = c(0.5, 1.0)
                        ) +
  guides(color = guide_colourbar(barwidth = 10, barheight = 1)) +
  coord_cartesian(ylim = c(0.0, 1.0)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
ggsave(file = paste(OutDir, "post_selection_coverage_significance20.png", sep = "/"),
       dpi = 600, height = 15, width = 20, unit = "cm"
       )
