##--------------------------------------------------------------------------------------------------------
## SCRIPT : Priors
##
## Authors : Matthieu Authier
## Last update : 2019-02-05
## R version 3.5.1 (2018-07-02) -- "Feather Spray"
## Copyright (C) 2018 The R Foundation for Statistical Computing
## Platform: x86_64-w64-mingw32/x64 (64-bit)
##--------------------------------------------------------------------------------------------------------

lapply(c("ggplot2", "ggthemes", "sn"), library, character.only=TRUE)

### clean up
rm(list = ls())

setwd(WorkDir <- getwd()) # set path to your working directory
DataDir <- paste(WorkDir, "data", sep = "/")
OutDir <- paste(WorkDir, "output", sep = "/")

### visualiser les diffrents priors
prior_df <- NULL
z <- qnorm(seq(0.001, 0.999, 0.001))

## prior informatif --> OR entre 0.5 et 2 avec proba = 0.95
prior_location <- 0
prior_scale <- log(2) / 2
prior_df <- rbind(prior_df,
                  data.frame(x = c(z, exp(z)),
                             y = rep(dnorm(z, prior_location, prior_scale), 2),
                             prior = rep("informative", 2 * length(z)),
                             scale = rep(c("log", "natural"), each = length(z))
                             )
                  )
## prior faiblement informatif de Cook et al. 
prior_location <- 0
prior_scale <- -log(2) * cos(pi * (0.025 - 0.5)) / sin(pi * (0.025 - 0.5))
prior_df <- rbind(prior_df,
                  data.frame(x = c(z, exp(z)),
                             y = rep(sn::dst(z, xi = prior_location, omega = prior_scale, nu = 1), 2),
                             prior = rep("weakly\ninformative", 2 * length(z)),
                             scale = rep(c("log", "natural"), each = length(z))
                             )
                  )

prior_df$prior <- factor(as.character(prior_df$prior), 
                         c("informative", "weakly\ninformative")
                         )
levels(prior_df$prior)

### graphique
theme_set(theme_bw(base_size = 16))
ggplot(data = prior_df,
       aes(x = x, y = y), color = "black"
       ) +
  geom_line() +
  facet_grid(prior~scale, scales = "free") +
  # scale_x_log10(breaks = c(0.33, 0.5, 0.75, 1, 1.33, 2, 3)) +
  xlab("x") + ylab("PDF") +
  guides(color = "none") +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text = element_text(size = 10),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 
ggsave(file = paste(OutDir, "Prior.png", sep = "/"), 
       dpi = 600, height = 15, width = 20, unit = "cm"
       )
