##--------------------------------------------------------------------------------------------------------
## SCRIPT : Priors
##
## Authors : Matthieu Authier
## Last update : 2019-12-11
## R version 3.5.2 (2018-12-20) -- "Eggshell Igloo"
## Copyright (C) 2018 The R Foundation for Statistical Computing
## Platform: x86_64-w64-mingw32/x64 (64-bit)
##--------------------------------------------------------------------------------------------------------

lapply(c("tidyverse", "ggplot2", "ggthemes", "cowplot", "sn"), library, character.only=TRUE)

### clean up
rm(list = ls())

setwd(WorkDir <- getwd()) # set path to your working directory
DataDir <- paste(WorkDir, "data", sep = "/")
OutDir <- paste(WorkDir, "output", sep = "/")

### visualiser les diffrents priors
prior_df <- NULL
z <- qnorm(seq(0.01, 0.99, 0.0001))

## prior informatif --> OR entre 0.5 et 2 avec proba = 0.95
prior_location <- 0
prior_scale <- log(2) / 2
prior_df <- rbind(prior_df,
                  data.frame(x = c(z, exp(z)),
                             y = rep(dnorm(z, prior_location, prior_scale, log = TRUE), 2),
                             prior = rep("informative", 2 * length(z)),
                             scale = rep(c("log", "natural"), each = length(z))
                             )
                  )
## prior faiblement informatif de Cook et al. 
prior_location <- 0
prior_scale <- -log(2) * cos(pi * (0.025 - 0.5)) / sin(pi * (0.025 - 0.5))
prior_df <- rbind(prior_df,
                  data.frame(x = c(z, exp(z)),
                             y = rep(sn::dst(z, xi = prior_location, omega = prior_scale, nu = 1, log = TRUE), 2),
                             prior = rep("weakly\ninformative", 2 * length(z)),
                             scale = rep(c("log", "natural"), each = length(z))
                             )
                  )

prior_df$prior <- factor(as.character(prior_df$prior), 
                         c("informative", "weakly\ninformative")
                         )
levels(prior_df$prior)

### graphique
theme_set(theme_bw(base_size = 16))

a <- ggplot(data = prior_df %>% filter(scale == "log"),
       aes(x = x, y = y, color = prior)
       ) +
  geom_line(size = 1.5) +
  facet_grid(. ~ scale, scales = "free_x") +
  scale_x_continuous(breaks = c(-log(5), -log(2), log(3/4), 0, log(4/3), log(2), log(5)),
                     labels = c(quote(log(1/5)), quote(log(1/2)), quote(log(3/4)), quote(log(1)), quote(log(4/3)), quote(log(2)), quote(log(5)))
                     ) +
  scale_y_continuous(breaks = c(0, -5, -10, -15, -20)) +
  xlab(quote(beta == log(r))) + ylab("log-density") +
  scale_color_colorblind() +
  coord_cartesian(xlim = c(log(1/5), log(5)), ylim = c(-15, 2)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text.x = element_text(size = 8),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        )
b <- ggplot(data = prior_df %>% filter(scale == "natural"),
            aes(x = x, y = y, color = prior)
            ) +
  geom_line(size = 1.5) +
  facet_grid(. ~ scale, scales = "free_x") +
  scale_x_continuous(breaks = c(1/5, 1/2, 3/4, 1, 4/3, 2, 5),
                     labels = c(quote(1/5), quote(1/2), quote(3/4), quote(1), quote(4/3), quote(2), quote(5))
                     ) +
  scale_y_continuous(breaks = c(0, -5, -10, -15, -20)) +
  xlab(quote(r == e^beta)) + ylab("log-density") +
  scale_color_colorblind() +
  guides(color = "none") +
  coord_cartesian(xlim = c(1/5, 5), ylim = c(-15, 2)) +
  theme(legend.position = "top", 
        plot.title = element_text(lineheight = 0.8, face = "bold"), 
        axis.text.x = element_text(size = 8),
        panel.grid.minor = element_blank(),
        panel.background = element_blank()
        ) 

# library(cowplot)
plot_grid(a, b, labels = c("A", "B"), align = "v", ncol = 1)
ggsave(file = paste(OutDir, "Prior_logdensity.png", sep = "/"), 
       dpi = 600, height = 15, width = 20, unit = "cm"
       )
