
make_data <- function(n, beta, upper_cv, precise_baseline = FALSE, rho = TRUE) {
  p <- seq(1, beta, length.out = n)
  if(precise_baseline) { cv <- c(0.1, runif(n - 1, 0.1, upper_cv)) }
  else{ cv <- runif(n, 0.1, upper_cv) }
  ### correlation between measurements
  if(rho) {
    rho_start <- runif(1, 0.70, 0.95)
    eps <- rchisq(n - 1, df = 2)
    eps <- rev(cumsum(eps))/sum(eps)
    eps <- c(1, rho_start * eps)
  }
  else { eps <- rep(0, n) }
  # plot(1:(n - 1), eps, ylim = c(0, 1), las = 1, bty = 'n')
  cv_p <- sqrt(cv[1] * cv[1] + cv * cv - 2 * cv[1] * cv * eps)
  sigmalog <- sqrt(log(1 + cv_p^2))
  mulog <- log(p / sqrt(1 + cv_p^2))
  # log_y <- c(0, rnorm(n - 1, mulog[-1], sigmalog[-1]))
  y <- c(1, rlnorm(n - 1, mulog[-1], sigmalog[-1]))
  return(data.frame(t = (1:n - 1) / (n-1),
                    y = y, #exp(log_y),
                    se = c(0.001, sigmalog[-1])
                    )
         )
}

trends <- function(n, beta, upper_cv, nu = 3, ...) {
  my_data <- make_data(n, beta, upper_cv, ...)
  # tlm
  # tlmfit <- hett::tlm(log(y) ~ -1 + t, data = my_data, start = list(dof = nu),
  #                     control = hett::tlm.control(maxit = 500, epsilon = 1e-7)
  #                     )
  # glm
  glmfit <- glm(log(y) ~ -1 + t, data = my_data, epsilon = 1e-7, maxit = 500)
  # arm
  armfit_cauchy <- arm::bayesglm(log(y) ~ -1 + t, 
                                 family = gaussian, 
                                 data = my_data,
                                 prior.mean = 0,
                                 prior.scale = -log(2) * cos(pi * (0.025 - 0.5)) / sin(pi * (0.025 - 0.5)),
                                 prior.df = 1,
                                 epsilon = 1e-7, maxit = 500
                                 )
  armfit_normal <- arm::bayesglm(log(y) ~ -1 + t, 
                                 family = gaussian, 
                                 data = my_data,
                                 prior.mean = 0,
                                 prior.scale = log(2) / 2,
                                 prior.df = Inf,
                                 epsilon = 1e-7, maxit = 500
                                 )
  df <- as.data.frame(rbind(#c(summary(tlmfit)$loc.summary$coefficients[-3], NA), 
                            c(summary(glmfit)$coefficients[-3], ifelse(glmfit$converged, 1, 0)),
                            c(summary(armfit_cauchy)$coefficients[-3], ifelse(armfit_cauchy$converged, 1, 0)),
                            c(summary(armfit_normal)$coefficients[-3], ifelse(armfit_normal$converged, 1, 0))
                            )
                      )
  names(df) <- c("theta", "se", "pval", "conv")
  df$n <- n
  df$cv <- upper_cv
  df$logbeta <- log(beta)
  df$model <- c("glm", "arm_weak", "arm_strong") #"tlm", 
  return(df)
}

# my_data <- make_data(n = 10, beta = 0.9, upper_cv = 0.5)
# summary(my_data)
# 
# trends(n = 10, beta = 0.9, upper_cv = 0.5, precise_baseline = FALSE)
# n_sim <- 1000
# 
# ### work at the moment
# system.time(
# dd <- do.call('rbind', 
#         lapply(1:n_sim, trends, n = 10, upper_cv = 0.5, beta = 0.5)
#         )
# )
### 1 min for 1000 rep so 10 minutes for 10000 ones

beta <- c(seq(0.5, 0.70, 0.025), seq(0.71, 0.99, 0.01))
study_length <- c(3:30)
n_sim <- 10000
